@@ -566,7 +566,12 @@ def _check_command_is_installed(command: str) -> None:
         try:
             import_module(command)
         except ImportError as exc:
-            raise ModuleNotFoundError(_get_command_not_found_msg(command)) from exc
+            if not os.path.isdir(command) and not os.path.isfile(
+                f"{command}.py"
+            ):  # pragma: nocover(py<37)
+                # I presume there lack of coverage in Python3.6 here is a bug, as all
+                # these branches are actually covered.
+                raise ModuleNotFoundError(_get_command_not_found_msg(command)) from exc
     else:
         if command in MIN_VERSIONS:
             min_version = MIN_VERSIONS[command]
