@@ -1,5 +1,6 @@
 """Parses the command line arguments provided."""
 import argparse
+import sys
 from textwrap import dedent
 from typing import Optional, Sequence
 
@@ -29,41 +30,28 @@ USAGE_MSG = dedent(
     See {DOCS_URL} for more details on how to run `nbqa`.
     """
 )
+DEPRECATED = {
+    "--nbqa-skip-bad-cells": (
+        "was deprecated in 0.13.0\n"
+        "Cells with invalid syntax are now skipped by default"
+    ),
+    "--nbqa-ignore-cells": "was deprecated in 0.8.0 and is now unnecessary",
+    "--nbqa-config": "was deprecated in 0.8.0 and is now unnecessary",
+}
 
 
 class CLIArgs:  # pylint: disable=R0902,R0903
-    """
-    Stores the command line arguments passed.
-
-    Attributes
-    ----------
-    command
-        The third-party tool to run (e.g. :code:`mypy`).
-    root_dirs
-        The notebooks or directories to run third-party tool on.
-    nbqa_mutate
-        Whether to allow 3rd party tools to modify notebooks.
-    nbqa_process_cells
-        Process code within these cell magics.
-    nbqa_addopts
-        Any additional flags passed to third-party tool (e.g. :code:`--quiet`).
-    nbqa_files
-        Global file include pattern.
-    nbqa_exclude
-        Global file exclude pattern.
-    nbqa_skip_bad_cells
-        Skip cells with syntax errors.
-    """
+    """Stores the command line arguments passed."""
 
     command: str
     root_dirs: Sequence[str]
-    nbqa_addopts: Sequence[str]
-    nbqa_mutate: bool
-    nbqa_process_cells: Optional[str]
-    nbqa_diff: bool
-    nbqa_files: Optional[str]
-    nbqa_exclude: Optional[str]
-    nbqa_skip_bad_cells: bool
+    addopts: Optional[Sequence[str]]
+    mutate: Optional[bool]
+    process_cells: Optional[Sequence[str]]
+    diff: Optional[bool]
+    files: Optional[str]
+    exclude: Optional[str]
+    dont_skip_bad_cells: Optional[bool]
 
     def __init__(self, args: argparse.Namespace, cmd_args: Sequence[str]) -> None:
         """
@@ -76,15 +64,27 @@ class CLIArgs:  # pylint: disable=R0902,R0903
         cmd_args
             Additional options to pass to the tool
         """
+        if cmd_args:
+            for deprecated in DEPRECATED:
+                if deprecated in cmd_args:
+                    sys.stderr.write(f"Flag {deprecated} {DEPRECATED[deprecated]}\n")
+                    sys.exit(1)
         self.command = args.command
         self.root_dirs = args.root_dirs
-        self.nbqa_addopts = cmd_args
-        self.nbqa_mutate = args.nbqa_mutate or False
-        self.nbqa_process_cells = args.nbqa_process_cells or None
-        self.nbqa_diff = args.nbqa_diff or False
-        self.nbqa_files = args.nbqa_files or None
-        self.nbqa_exclude = args.nbqa_exclude or None
-        self.nbqa_skip_bad_cells = args.nbqa_skip_bad_cells or False
+        self.addopts = cmd_args or None
+        self.mutate = args.nbqa_mutate or None
+        if args.nbqa_process_cells is not None:
+            self.process_cells = args.nbqa_process_cells.split(",")
+        else:
+            self.process_cells = None
+        self.diff = args.nbqa_diff or None
+        self.files = args.nbqa_files
+        self.exclude = args.nbqa_exclude
+        self.dont_skip_bad_cells = args.nbqa_dont_skip_bad_cells or None
+        if args.nbqa_skip_celltags is not None:
+            self.skip_celltags = args.nbqa_skip_celltags.split(",")
+        else:
+            self.skip_celltags = None
 
     @staticmethod
     def parse_args(argv: Optional[Sequence[str]]) -> "CLIArgs":
@@ -141,9 +141,18 @@ class CLIArgs:  # pylint: disable=R0902,R0903
             "--version", action="version", version=f"nbqa {__version__}"
         )
         parser.add_argument(
-            "--nbqa-skip-bad-cells",
+            "--nbqa-dont-skip-bad-cells",
             action="store_true",
-            help="Skip cells with invalid syntax.",
+            help="Don't skip cells with invalid syntax.",
+        )
+        parser.add_argument(
+            "--nbqa-skip-celltags",
+            required=False,
+            help=dedent(
+                r"""
+                Skip cells with have any of the given celltags.
+                """
+            ),
         )
         args, cmd_args = parser.parse_known_args(argv)
         return CLIArgs(args, cmd_args)
